%global pyname certbot-dns-google

%if 0%{?rhel} && 0%{?rhel} <= 7
%bcond_with python3
%else
%bcond_without python3
%endif

%if 0%{?fedora} && 0%{?fedora} >= 30
%bcond_with python2
%else
%bcond_without python2
%endif

Name:           python-%{pyname}
Version:        0.35.1
Release:        1%{?dist}
Summary:        Google Cloud DNS Authenticator plugin for Certbot

License:        ASL 2.0
URL:            https://pypi.python.org/pypi/certbot-dns-google
Source0:        https://files.pythonhosted.org/packages/source/c/%{pyname}/%{pyname}-%{version}.tar.gz

BuildArch:      noarch

%if %{with python2}
BuildRequires:  python2-acme >= 0.29.0
BuildRequires:  python2-certbot >= 0.34.0
BuildRequires:  python2-devel
BuildRequires:  python2-google-api-client
BuildRequires:  python2-mock
BuildRequires:  python2-oauth2client
BuildRequires:  python2-setuptools
BuildRequires:  python2-zope-interface
%if 0%{?rhel} && 0%{?rhel} <= 7
# EL7 has unversioned names for these packages
BuildRequires:  python-httplib2
%else
BuildRequires:  python2-httplib2
%endif
%endif

%if %{with python3}
BuildRequires:  python3-acme >= 0.29.0
BuildRequires:  python3-certbot >= 0.34.0
BuildRequires:  python3-devel
BuildRequires:  python3-google-api-client
BuildRequires:  python3-httplib2
BuildRequires:  python3-mock
BuildRequires:  python3-oauth2client
BuildRequires:  python3-setuptools
BuildRequires:  python3-zope-interface
%endif

%description
This certbot plugin automates the process of completing an ACME
dns-01 challenge by creating, and subsequently removing, TXT
records using Google Cloud DNS.

%if %{with python2}
%package -n python2-%{pyname}
# Provide the name users expect as a certbot plugin
%if 0%{?rhel} && 0%{?rhel} <= 7
Provides:       %{pyname} = %{version}-%{release}
%endif
# Although a plugin for the certbot command it's technically
# an extension to the certbot python libraries
Requires:       python2-acme >= 0.29.0
Requires:       python2-certbot >= 0.34.0
Requires:       python2-google-api-client
Requires:       python2-mock
Requires:       python2-oauth2client
Requires:       python2-zope-interface
%if 0%{?rhel} && 0%{?rhel} <= 7
# EL7 has unversioned names for these packages
Requires:       python-httplib2
%else
Requires:       python2-httplib2
%endif

%if 0%{?fedora}
#Recommend the CLI as that will be the interface most use
Recommends:     certbot >= 0.34.0
%else
Requires:       certbot >= 0.34.0
%endif
Summary:        %{summary}
%{?python_provide:%python_provide python2-%{pyname}}

%description -n python2-%{pyname}
This certbot plugin automates the process of completing an ACME
dns-01 challenge by creating, and subsequently removing, TXT
records using Google Cloud DNS.

This is the Python 2 version of the package.
%endif

%if %{with python3}
%package -n python3-%{pyname}
# Provide the name users expect as a certbot plugin
%if 0%{?fedora}
Provides:       %{pyname} = %{version}-%{release}
%endif
# Although a plugin for the certbot command it's technically
# an extension to the certbot python libraries
Requires:       python3-acme >= 0.29.0
Requires:       python3-certbot >= 0.34.0
Requires:       python3-google-api-client
Requires:       python3-httplib2
Requires:       python3-mock
Requires:       python3-oauth2client
Requires:       python3-zope-interface

%if 0%{?fedora}
#Recommend the CLI as that will be the interface most use
Recommends:     certbot >= 0.34.0
%else
Requires:       certbot >= 0.34.0
%endif
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pyname}}

%description -n python3-%{pyname}
This certbot plugin automates the process of completing an ACME
dns-01 challenge by creating, and subsequently removing, TXT
records using Google Cloud DNS.

This is the Python 3 version of the package.
%endif

%prep
%autosetup -p1 -n %{pyname}-%{version}

%build
%if %{with python2}
%py2_build
%endif

%if %{with python3}
%py3_build
%endif

%check
%if %{with python2}
%{__python2} setup.py test
%endif

%if %{with python3}
%{__python3} setup.py test
%endif

%install
%if %{with python2}
%py2_install
%endif

%if %{with python3}
%py3_install
%endif

%if %{with python2}
%files -n python2-%{pyname}
%license LICENSE.txt
%doc README.rst
%{python2_sitelib}/certbot_dns_google
%{python2_sitelib}/certbot_dns_google-%{version}*.egg-info
%endif

%if %{with python3}
%files -n python3-%{pyname}
%license LICENSE.txt
%doc README.rst
%{python3_sitelib}/certbot_dns_google
%{python3_sitelib}/certbot_dns_google-%{version}*.egg-info
%endif

%changelog
* Fri Jun 21 2019 Eli Young <elyscape@gmail.com> - 0.35.1-1
- Update to 0.35.1 (#1717685)

* Tue May 28 2019 Eli Young <elyscape@gmail.com> - 0.34.2-1
- Update to 0.34.2 (#1686192)

* Fri Feb 08 2019 Eli Young <elyscape@gmail.com> - 0.31.0-1
- Update to 0.31.0 (#1673754)

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.30.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jan 28 2019 Eli Young <elyscape@gmail.com> - 0.30.2-1
- Update to 0.30.2 (#1669321)

* Tue Dec 11 2018 Eli Young <elyscape@gmail.com> - 0.29.1-1
- Update to 0.29.1
- Remove Python 2 package in Fedora 30+ (#1654016)

* Wed Nov 14 2018 Eli Young <elyscape@gmail.com> - 0.28.0-1
- Update to 0.28.0

* Mon Sep 10 2018 Eli Young <elyscape@gmail.com> - 0.27.1-1
- Update to 0.27.1 (#1627577)

* Tue Jul 17 2018 Eli Young <elyscape@gmail.com> - 0.26.1-1
- Update to 0.26.1 (#1600299)

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.25.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 0.25.1-2
- Rebuilt for Python 3.7

* Wed Jun 13 2018 Eli Young <elyscape@gmail.com> - 0.25.1-1
- Update to 0.25.1 (#1591038)

* Thu Jun 07 2018 Eli Young <elyscape@gmail.com> - 0.25.0-1
- Update to 0.25.0 (#1588226)

* Wed May 02 2018 Eli Young <elyscape@gmail.com> - 0.24.0-1
- Update to 0.24.0 (#1574143)

* Thu Apr 05 2018 Eli Young <elyscape@gmail.com> - 0.23.0-1
- Update to 0.23.0 (#1563906)

* Tue Mar 20 2018 Eli Young <elyscape@gmail.com> - 0.22.2-1
- Update to 0.22.2

* Sat Mar 10 2018 Eli Young <elyscape@gmail.com> - 0.22.0-1
- Update to 0.22.0

* Mon Feb 26 2018 Nick Bebout <nb@usi.edu> - 0.21.1-2
- Simplify deps, add python2- prefix where available

* Wed Feb 14 2018 Eli Young <elyscape@gmail.com> - 0.21.1-1
- Initial package (#1544555)
